==> RSTouchscreenNG-0.92.2.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/select.service.ts <==
/* (C) 2016-2019 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, Injectable} from '@angular/core';
import {RSModal} from './modal.service';
import {RSModalViewComponent} from './modal-view.component';

@Injectable()
export class RSSelect {
    constructor(public modal: RSModal) {
    }

    select(list: any, field: string, title: string): Promise<any> {
        return this.modal.show(RSSelectModalComponent, {list: list, field: field, title: title});
    }
}

@Component({
    selector: 'rs-select-modal',
    template: `
    <rs-modal-head [innerHTML]="modal.data.title"></rs-modal-head>
    <rs-modal-content>
        <div *ngFor="let s of modal.data.list">
            <rs-button class="primary select full" (hit)="modal.close(s)">{{s[modal.data.field]}}</rs-button>
        </div>
    </rs-modal-content>
    <rs-modal-footer><rs-button (hit)="modal.cancel()" class="secondary select full">Cancel</rs-button></rs-modal-footer>
    `
})
export class RSSelectModalComponent {
    constructor(public modal: RSModalViewComponent) {
    }
}

==> RSTouchscreenNG-0.94.3.zip: RSTouchscreenNG/projects/front-ui/src/lib/modals/select.service.ts <==
/* (C) 2016-2020 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, Injectable} from '@angular/core';
import {RSModal} from './modal.service';
import {RSModalViewComponent} from './modal-view.component';

@Injectable()
export class RSSelect {
    constructor(public modal: RSModal) {
    }

    select(list: any, field: string, title: string): Promise<any> {
        return this.modal.show(RSSelectModalComponent, {list: list, field: field, title: title});
    }
}

@Component({
    selector: 'rs-select-modal',
    template: `
    <rs-modal-head [innerHTML]="modal.data.title"></rs-modal-head>
    <rs-modal-content>
        <div *ngFor="let s of modal.data.list">
            <rs-button class="primary select full" (hit)="modal.close(s)"><i *ngIf="s.icon" [class]="s.icon"></i> {{s[modal.data.field]}}</rs-button>
        </div>
    </rs-modal-content>
    <rs-modal-footer><rs-button (hit)="modal.cancel()" class="secondary select full"><i class="fa fa-times"></i> Cancel</rs-button></rs-modal-footer>
    `
})
export class RSSelectModalComponent {
    constructor(public modal: RSModalViewComponent) {
    }
}
